@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tomorrow-night-deepblue-theme" "1.2.4"
+(define-package "tomorrow-night-deepblue-theme" "20251015.1359"
   "The Tomorrow Night Deepblue color theme."
   '((emacs "26.1"))
   :url "https://github.com/jamescherti/tomorrow-night-deepblue-theme.el"
-  :commit "0c9ee6ba3b2fbdf4ab37cf486d9b0f1f7de09a71"
-  :revdesc "1.2.4-0-g0c9ee6ba3b2f"
+  :commit "85084ded2c4f792aaed4a4a1687dadea0347c858"
+  :revdesc "85084ded2c4f"
   :keywords '("faces" "themes"))
